from setuptools import setup, find_packages

setup(
    name='zjbbintest',
    version='2.1',
    author="zhangjiabin01",
    author_email="zhangjiabin01@baidu.com",
    description="bintest自动化框架",
    packages=find_packages(),
    install_requires=[
        'attrs==23.2.0',
        'certifi==2024.2.2',
        'charset-normalizer==3.3.2',
        'idna==3.7',
        'importlib_resources==6.4.0',
        'Jinja2==3.1.4',
        'jsonschema==4.21.1',
        'jsonschema-specifications==2023.12.1',
        'MarkupSafe==2.1.5',
        'pkgutil_resolve_name==1.3.10',
        'referencing==0.34.0',
        'requests==2.31.0',
        'rpds-py==0.18.0',
        'urllib3==2.2.1',
        'zipp==3.18.1',
    ],
)


"""
Copyright (c) 2024 Baidu.com, Inc. All Rights Reserved
This module provide configigure file management service in i18n environment.

Authors: zhangjiabin01
Date: 2024/4/10 16:00:00
actuator的作用是执行单条case，并返回执行结果
TODO 可以把执行器当作一个对象，这个对象主要有三个部分，分别为case_json、执行状态和执行结果
执行状态是一个枚举，未执行，执行成功，执行失败
执行结果是一个执行结果对象
TODO 执行结果对象的结构需要再想想
"""


# class SingleStepActuator:
#     """
#     单步执行器，执行单条case的一个步骤
#     """
#
#     def __init__(self):
#         """
#         :return:
#         """
#         self.requestor =

